<?php

namespace EventPortal\Tests\Unit\Agenda\Actions;

use EventPortal\Domain\Agenda\Actions\DeleteAgenda;
use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class DeleteAgendaTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_delete_agenda()
    {
        $agenda = factory(Agenda::class)->create();

        $pathwayA = factory(Pathway::class)->create(['agenda_id' => $agenda->id]);
        $sessionA = factory(Session::class)->create(['pathway_id' => $pathwayA->id]);
        $sessionB = factory(Session::class)->create(['pathway_id' => $pathwayA->id]);

        $pathwayB = factory(Pathway::class)->create(['agenda_id' => $agenda->id]);
        $sessionC = factory(Session::class)->create(['pathway_id' => $pathwayB->id]);
        $sessionD = factory(Session::class)->create(['pathway_id' => $pathwayB->id]);

        (new DeleteAgenda)->execute($agenda);

        $this
            ->assertDatabaseMissing('agendas', [
                'id' => $agenda->id,
            ])
            ->assertDatabaseMissing('pathways', [
                'id' => $pathwayA->id,
                'agenda_id' => $agenda->id,
            ])
            ->assertDatabaseMissing('sessions', [
                'id' => $sessionA->id,
                'pathway_id' => $pathwayA->id,
            ])
            ->assertDatabaseMissing('sessions', [
                'id' => $sessionB->id,
                'pathway_id' => $pathwayA->id,
            ])
            ->assertDatabaseMissing('pathways', [
                'id' => $pathwayB->id,
                'agenda_id' => $agenda->id,
            ])
            ->assertDatabaseMissing('sessions', [
                'id' => $sessionC->id,
                'pathway_id' => $pathwayB->id,
            ])
            ->assertDatabaseMissing('sessions', [
                'id' => $sessionD->id,
                'pathway_id' => $pathwayB->id,
            ]);
    }
}
